@@ -1,5 +1,5 @@
 magcon <-
-function(x,y,h,doim=TRUE,docon=TRUE,dobar=TRUE,n=100,add=FALSE,xlab='',ylab='',imcol=rev(rainbow(1000,start=0,end=2/3)),conlevels=c(0.5,pnorm(1)-pnorm(-1),0.95), barposition='topright', barorient='v',bartitle='Contained %',bartitleshift=0,xlim=NULL,ylim=NULL,weights=NA,...){
+function(x,y,h,doim=TRUE,docon=TRUE,dobar=TRUE,n=100,add=FALSE,xlab='',ylab='',imcol=c(NA,rev(rainbow(1000,start=0,end=2/3))),conlevels=c(0.5,pnorm(1)-pnorm(-1),0.95), barposition='topright', barorient='v',bartitle='Contained %',bartitleshift=0,xlim=NULL,ylim=NULL,weights=NA,...){
 ngrid=n*2
 if(missing(y)){
   if(!is.null(dim(x))){
@@ -34,7 +34,7 @@ if(doim){
   image(tempcon,col=imcol,axes=FALSE,add=TRUE,xlim=xlim,ylim=ylim)
 }
 if(doim & docon){contour(tempcon,levels=conlevels,add=TRUE,drawlabels=F,axes=FALSE,...)}
-if(doim==FALSE & docon){contour(tempcon,levels=conlevels,add=add,drawlabels=F,axes=FALSE,xlim=xlim,ylim=ylim,...)}
+if(doim==FALSE & docon){contour(tempcon,levels=conlevels,add=add,drawlabels=F,axes=FALSE,xlim=xlim,ylim=ylim,...);box()}
 if(add==FALSE){magaxis(xlab=xlab,ylab=ylab)}
 if(doim & dobar){magbar(position=barposition,range=c(0,100),orient=barorient,col=rev(imcol),title=bartitle,titleshift=bartitleshift)}
 return=tempcon
