@@ -1,5 +1,5 @@
 magmap<-
-function(data, lo=0, hi=1, flip=FALSE, range=c(0,2/3), type='quan', stretch='lin', stretchscale=1, bad=NA, clip=''){
+function(data, locut=0, hicut=1, flip=FALSE, range=c(0,2/3), type='quan', stretch='lin', stretchscale=1, bad=NA, clip=''){
 if(stretchscale=='auto'){
   good=is.na(data)==FALSE & is.nan(data)==FALSE & is.infinite(data)==FALSE & is.null(data)==FALSE
 	if(length(which(good))==0){stop('There is no numeric data!')}
@@ -18,58 +18,58 @@ if(stretch=='log' | stretch=='sqrt'){
 }
   
 if(type=='quan'){
-	lo=quantile(data[good],lo)
-	hi=quantile(data[good],hi)
+	locut=quantile(data[good],locut)
+	hicut=quantile(data[good],hicut)
 }else if(type=='num'){
-	lo=lo
-	hi=hi
+	locut=locut
+	hicut=hicut
 }else if(type=='sig'){
-	lo=quantile(data[good],pnorm(lo))
-	hi=quantile(data[good],pnorm(hi))
+	locut=quantile(data[good],pnorm(locut))
+	hicut=quantile(data[good],pnorm(hicut))
 }else if(type=='rank'){
-	lo=1
-	hi=length(data[good])
-	data[good][order(data[good])]=lo:hi
+	locut=1
+	hicut=length(data[good])
+	data[good][order(data[good])]=locut:hicut
 }else{
   stop(type,'is not a valid type option!')
 }
-loreturn=lo
-hireturn=hi
-if(stretch=='log' & lo<=0){stop('lo <= 0 and stretch=\'log\'- this is not allowed!')}
-if(stretch=='log' & hi<=0){stop('hi <=0 and stretch=\'log\'- this is not allowed!')}
-if(lo>hi){stop('lo>hi is not allowed')}
-if(lo==hi){data[good][1:length(data)]=(range[2]+range[1])/2}
-if(lo<hi){
+loreturn=locut
+hireturn=hicut
+if(stretch=='log' & locut<=0){stop('locut <= 0 and stretch=\'log\'- this is not allowed!')}
+if(stretch=='log' & hicut<=0){stop('hicut <=0 and stretch=\'log\'- this is not allowed!')}
+if(locut>hicut){stop('locut>hicut is not allowed')}
+if(locut==hicut){data[good][1:length(data)]=(range[2]+range[1])/2}
+if(locut<hicut){
   if(stretch=='lin'){
   #Nothing to see here...
   }else if(stretch=='log'){
-	  lo=log10(lo)
-	  hi=log10(hi)
+	  locut=log10(locut)
+	  hicut=log10(hicut)
     data=suppressWarnings(log10(data))
 	}else if(stretch=='atan'){
-    lo=atan(lo*stretchscale)
-    hi=atan(hi*stretchscale)
+    locut=atan(locut*stretchscale)
+    hicut=atan(hicut*stretchscale)
     data=atan(data*stretchscale)
   }else if(stretch=='asinh'){
-	  lo=asinh(lo*stretchscale)
-	  hi=asinh(hi*stretchscale)
+	  locut=asinh(locut*stretchscale)
+	  hicut=asinh(hicut*stretchscale)
     data=asinh(data*stretchscale)
 	}else if(stretch=='sqrt'){
-	  lo=sqrt(lo)
-	  hi=sqrt(hi)
+	  locut=sqrt(locut)
+	  hicut=sqrt(hicut)
     data=suppressWarnings(sqrt(data))
 	}else if(stretch=='cdf'){
     cdf=ecdf(data[good])
-    lo=cdf(lo)
-    hi=cdf(hi)
+    locut=cdf(locut)
+    hicut=cdf(hicut)
     data[good]=cdf(data[good])
   }else{
 	  stop(paste(stretch,'is not a valid stretch option!'))
 	}
-  losel=data<lo & good; hisel=data>hi & good
-	data[losel]=lo; data[hisel]=hi
-	data[good]=data[good]-lo
-	data[good]=range[1]+(data[good]*(range[2]-range[1])/(hi-lo))
+  losel=data<locut & good; hisel=data>hicut & good
+	data[losel]=locut; data[hisel]=hicut
+	data[good]=data[good]-locut
+	data[good]=range[1]+(data[good]*(range[2]-range[1])/(hicut-locut))
 	if(flip){data[good]=range[2]-data[good]+range[1]}
   if(clip=='NA'){data[losel]=NA;data[hisel]=NA}
 }
